@@ -3,9 +3,10 @@
 #' Automatic tuning of random forests of the \code{\link[ranger]{ranger}} package with one line of code. 
 #'
 #' @param task The mlr task created by \code{\link[mlr]{makeClassifTask}} or \code{\link[mlr]{makeRegrTask}}. 
-#' @param measure Performance measure to evaluate/optimize. Default is brier score for classification and mse for regression. Can be changed to accuracy, AUC or logaritmic loss by setting it to \code{list(acc)}, \code{list(auc)} or \code{list(logloss)}. Other possible performance measures from mlr can be looked up here: \url{https://mlr-org.github.io/mlr-tutorial/release/html/performance/index.html}
+#' @param measure Performance measure to evaluate/optimize. Default is brier score for classification and mse for regression. Can be changed to accuracy, AUC or logaritmic loss by setting it to \code{list(acc)}, \code{list(auc)} or \code{list(logloss)}. Other possible performance measures from mlr can be looked up in the \href{https://mlr-org.github.io/mlr/articles/measures.html}{mlr tutorial}. 
 #' @param iters Number of iterations. Default is 70.
 #' @param iters.warmup Number of iterations for the warmup. Default is 30. 
+#' @param time.budget Running time budget in seconds. Note that the actual mbo run can take more time since the condition is checked after each iteration. The default NULL means: There is no time budget.
 #' @param num.threads Number of threads. Default is number of CPUs available.
 #' @param num.trees Number of trees.
 #' @param parameters Optional list of fixed named parameters that should be passed to \code{\link[ranger]{ranger}}.
@@ -21,9 +22,12 @@
 #' @param show.info Verbose mlrMBO output on console? Default is \code{TRUE}.
 #' @import ranger mlr mlrMBO ParamHelpers BBmisc stats smoof lhs parallel
 #' @importFrom DiceKriging km predict.km
-#' @return list with recommended parameters and a data.frame with all evaluated hyperparameters and performance and time results for each run
+#' @return A list with elements
+#'   \item{\code{recommended.pars}}{Recommended hyperparameters.}
+#'   \item{\code{results}}{A data.frame with all evaluated hyperparameters and performance and time results for each run.}
+#'   \item{\code{model}}{The final model if \code{build.final.model} set to TRUE.}
 #' @details Model based optimization is used as tuning strategy and the three parameters min.node.size, sample.fraction and mtry are tuned at once. Out-of-bag predictions are used for evaluation, which makes it much faster than other packages and tuning strategies that use for example 5-fold cross-validation. Classification as well as regression is supported. 
-#' The measure that should be optimized can be chosen from the list of measures in mlr: http://mlr-org.github.io/mlr-tutorial/devel/html/measures/index.html
+#' The measure that should be optimized can be chosen from the list of measures in mlr: \href{https://mlr-org.github.io/mlr/articles/measures.html}{mlr tutorial}
 #' @seealso \code{\link{estimateTimeTuneRanger}} for time estimation and \code{\link{restartTuneRanger}} for continuing the algorithm if there was an error. 
 #' @export
 #' @examples 
@@ -47,7 +51,7 @@
 #' res$model
 #' # Prediction
 #' predict(res$model, newdata = iris[1:10,])}
-tuneRanger = function(task, measure = NULL, iters = 70, iters.warmup = 30, num.threads = NULL, num.trees = 1000, 
+tuneRanger = function(task, measure = NULL, iters = 70, iters.warmup = 30, time.budget = NULL, num.threads = NULL, num.trees = 1000, 
   parameters = list(replace = FALSE, respect.unordered.factors = "order"), 
   tune.parameters = c("mtry", "min.node.size", "sample.fraction"), save.file.path = NULL,
   build.final.model = TRUE, show.info = getOption("mlrMBO.show.info", TRUE)) {
@@ -143,7 +147,7 @@ tuneRanger = function(task, measure = NULL, iters = 70, iters.warmup = 30, num.t
   
   control = makeMBOControl(n.objectives = 1L, propose.points = mbo.prop.points, # impute.y.fun = function(x, y, opt.path) 0.7, 
     save.on.disk.at = save.on.disk.at, save.file.path = save.file.path)
-  control = setMBOControlTermination(control, max.evals = f.evals, iters = iters)
+  control = setMBOControlTermination(control, max.evals = f.evals, iters = iters, time.budget = time.budget)
   control = setMBOControlInfill(control, #opt = infill.opt,
     opt.focussearch.maxit = mbo.focussearch.maxit,
     opt.focussearch.points = mbo.focussearch.points,
